idp

package
v0.1.11 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 20, 2023 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

func New

func New(client *hcloud.Client) *Client

func (*Client) ActivateTOTP added in v0.0.21

func (*Client) CreateOAuthApplication added in v0.0.21

func (c *Client) CreateOAuthApplication(organization string, oauthApplication *entities.OAuthApplicationCreation) (*entities.OAuthApplication, *http.Response, *hcloud.ErrorResponse)

func (*Client) CreateOAuthApplicationSecret added in v0.0.21

func (c *Client) CreateOAuthApplicationSecret(organization string, oauthApplicationId string, secret *entities.OAuthApplicationClientSecretCreation) (*entities.OAuthApplication, *http.Response, *hcloud.ErrorResponse)

func (*Client) CreateOrganization

func (c *Client) CreateOrganization(organization *entities.Organization) (*entities.Organization, *http.Response, *hcloud.ErrorResponse)

CreateOrganization returns the new organization

func (*Client) CreatePat added in v0.0.21

func (*Client) CreateTeam added in v0.0.21

func (c *Client) CreateTeam(organization string, team *entities.TeamCreation) (*entities.Team, *http.Response, *hcloud.ErrorResponse)

func (*Client) DeleteOAuthApplication added in v0.0.21

func (c *Client) DeleteOAuthApplication(organization string, oauthApplicationId string) (*http.Response, *hcloud.ErrorResponse)

func (*Client) DeleteOAuthApplicationSecret added in v0.0.21

func (c *Client) DeleteOAuthApplicationSecret(organization string, oauthApplicationId string, secret string) (*entities.OAuthApplication, *http.Response, *hcloud.ErrorResponse)

func (*Client) DeleteOrganization added in v0.0.21

func (c *Client) DeleteOrganization(name string) (*http.Response, *hcloud.ErrorResponse)

DeleteOrganizationByName deletes an organization by name

func (*Client) DeleteOrganizationMember added in v0.0.21

func (c *Client) DeleteOrganizationMember(organization string, userId string) (*http.Response, *hcloud.ErrorResponse)

func (*Client) DeletePat added in v0.0.21

func (c *Client) DeletePat(patId string) (*http.Response, *hcloud.ErrorResponse)

func (*Client) DeletePats added in v0.0.21

func (c *Client) DeletePats() (*http.Response, *hcloud.ErrorResponse)

func (*Client) DeleteTeam added in v0.0.21

func (c *Client) DeleteTeam(organization string, teamId string) (*http.Response, *hcloud.ErrorResponse)

func (*Client) DeleteUser added in v0.0.20

func (c *Client) DeleteUser() (*entities.User, *http.Response, *hcloud.ErrorResponse)

DeleteUser deletes the user behind the current active token

THIS OPERATION CAN NOT BE UNDONE

func (*Client) DeleteUserSessions added in v0.0.20

func (c *Client) DeleteUserSessions() (*http.Response, *hcloud.ErrorResponse)

DeleteUserSessions deletes all active sessions of the user for the active token

Deleting all sessions will forcibly logout all devices and invalidate all existing JWT Tokens for this account

func (*Client) DisableTOTP added in v0.0.21

func (c *Client) DisableTOTP(token *entities.TOTPToken) (*http.Response, *hcloud.ErrorResponse)

func (*Client) EnableTOTP added in v0.0.21

func (c *Client) EnableTOTP() (*entities.TOTP, *http.Response, *hcloud.ErrorResponse)

func (*Client) GetOAuthApplication added in v0.0.21

func (c *Client) GetOAuthApplication(organization string, oauthApplicationId string) (*entities.OAuthApplication, *http.Response, *hcloud.ErrorResponse)

func (*Client) GetOAuthApplications added in v0.0.21

func (c *Client) GetOAuthApplications(organization string, limit int, page int) (*[]entities.OAuthApplication, entities.Total, *http.Response, *hcloud.ErrorResponse)

func (*Client) GetOrganization added in v0.0.21

func (c *Client) GetOrganization(name string) (*entities.Organization, *http.Response, *hcloud.ErrorResponse)

GetOrganizationByName returns a given organization if found

func (*Client) GetOrganizationMembers added in v0.0.21

func (c *Client) GetOrganizationMembers(organization string, limit int, page int) (*[]entities.OrganizationMember, entities.Total, *http.Response, *hcloud.ErrorResponse)

func (*Client) GetPats added in v0.0.21

func (c *Client) GetPats(limit int, page int) (*[]entities.UserPat, *http.Response, *hcloud.ErrorResponse)

func (*Client) GetTeam added in v0.0.21

func (c *Client) GetTeam(organization string, teamId string) (*entities.Team, *http.Response, *hcloud.ErrorResponse)

func (*Client) GetTeams added in v0.0.21

func (c *Client) GetTeams(organization string, limit int, page int) (*[]entities.Team, entities.Total, *http.Response, *hcloud.ErrorResponse)

func (*Client) GetUser added in v0.0.20

func (c *Client) GetUser() (*entities.User, *http.Response, *hcloud.ErrorResponse)

GetUser returns the user for the active token

func (*Client) GetUserEmail added in v0.0.20

func (c *Client) GetUserEmail() (*entities.UserEmail, *http.Response, *hcloud.ErrorResponse)

GetUserEmail returns the email of the user for the active token

func (*Client) GetUserNats added in v0.0.20

GetUserNats returns the allowed nats permissions for the active token

func (*Client) GetUserOrganizations added in v0.0.20

func (c *Client) GetUserOrganizations(limit int, page int) (*[]entities.Organization, entities.Total, *http.Response, *hcloud.ErrorResponse)

GetUserOrgs returns all organizations of the user for the active token

func (*Client) InviteOrganizationMember added in v0.0.21

func (c *Client) InviteOrganizationMember(organization string, member *entities.OrganizationMemberCreation) (*entities.OrganizationMember, *http.Response, *hcloud.ErrorResponse)

func (*Client) Login added in v0.0.19

func (c *Client) Login(login *entities.Login) (*entities.Token, *hcloud.ErrorResponse)

func (*Client) PatchOAuthApplicationSecret added in v0.0.21

func (c *Client) PatchOAuthApplicationSecret(organization string, oauthApplicationId string, secret string, secretName *entities.OAuthApplicationClientSecretCreation) (*entities.OAuthApplication, *http.Response, *hcloud.ErrorResponse)

func (*Client) PatchOrganizationMemberPermission added in v0.0.21

func (c *Client) PatchOrganizationMemberPermission(organization string, userId string, permission *entities.PatchOrganizationMemberPermission) (*entities.OrganizationMember, *http.Response, *hcloud.ErrorResponse)

func (*Client) PatchTeam added in v0.0.21

func (c *Client) PatchTeam(organization string, teamId string, team *entities.TeamPatchUserOperation) (*entities.Team, *http.Response, *hcloud.ErrorResponse)

func (*Client) PatchUser added in v0.0.19

func (c *Client) PatchUser(user *entities.PatchUser) (*entities.User, *http.Response, *hcloud.ErrorResponse)

PatchUser returns the user patched, given user

func (*Client) Register

func (c *Client) Register(register *entities.Register) (*entities.User, *hcloud.ErrorResponse)

Register registers a new user in the system

entities.Register requires a captcha code which has go be generated manually Link: https://app.helmut.cloud/docs/register#captcha TODO: fix link

func (*Client) SearchUserOrganizations added in v0.0.20

func (c *Client) SearchUserOrganizations(filter *entities.SearchOrganizationFilter, limit int, page int) (*[]entities.Organization, entities.Total, *http.Response, *hcloud.ErrorResponse)

SearchUserOrgs returns all organizations of the user for the active token for the given search filter

func (*Client) UpdateOAuthApplication added in v0.0.21

func (c *Client) UpdateOAuthApplication(organization string, oauthApplicationId string, oauthApplication *entities.OAuthApplicationUpdate) (*entities.OAuthApplication, *http.Response, *hcloud.ErrorResponse)

func (*Client) UpdatePat added in v0.0.21

func (*Client) VerifyRegistration added in v0.0.20

func (c *Client) VerifyRegistration(registerVerify *entities.RegisterVerify) (*entities.User, *hcloud.ErrorResponse)

RegisterVerify verifies a previous registration

Registrations must be verified using the activationCode being sent to the E-Mail address provided during registration Link: https://app.helmut.cloud/docs/register#verify TODO: fix link

func (*Client) Version

func (c *Client) Version() (*entities.Version, *http.Response, *hcloud.ErrorResponse)

Jump to