Documentation
¶
Index ¶
- type AuditLog
- type Cronjob
- type CronjobCreation
- type CronjobExpression
- type CronjobHeader
- type CronjobHttpMethod
- type CronjobInternal
- type CronjobLog
- type CronjobLogCreation
- type Event
- type EventCreation
- type FuseSpace
- type High5Space
- type Login
- type NatsPermissions
- type OAuthApplication
- type OAuthApplicationClientSecret
- type OAuthApplicationClientSecretCreation
- type OAuthApplicationCreation
- type OAuthApplicationUpdate
- type Organization
- type OrganizationMember
- type OrganizationMemberCreation
- type OrganizationPermission
- type PatchOrganizationMemberPermission
- type PatchUser
- type PatchWebhook
- type Permission
- type ReducedOrganization
- type ReducedUser
- type Register
- type RegisterVerify
- type Scope
- type SearchDateFilter
- type SearchDateOperator
- type SearchOrganizationFilter
- type Space
- type SpaceCreation
- type SpacePermission
- type SpacePermissionPatch
- type Stream
- type StreamCreation
- type StreamExecutionPayload
- type StreamExecutionRequest
- type StreamOrder
- type StreamPayloadType
- type StreamResult
- type TOTP
- type TOTPActivated
- type TOTPToken
- type Team
- type TeamCreation
- type TeamPatch
- type TeamPatchUserOperation
- type Token
- type Total
- type User
- type UserEmail
- type UserPat
- type UserPatCreation
- type UserPatPatch
- type UserPatType
- type Version
- type Webhook
- type WebhookCreation
- type WebhookLog
- type WebhookSecurityHeaders
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cronjob ¶
type Cronjob struct {
Id string `json:"_id,omitempty"`
Enabled bool `json:"enabled,omitempty"`
Name string `json:"name,omitempty"`
Description string `json:"description,omitempty"`
Expression string `json:"expression,omitempty"`
Target string `json:"targetUrl,omitempty"`
Method CronjobHttpMethod `json:"httpMethod,omitempty"`
AcceptInvalidSSL bool `json:"acceptInvalidSSL,omitempty"`
Timezone string `json:"timezone,omitempty"`
Creator ReducedUser `json:"creator,omitempty"`
CreateDate int `json:"createDate,omitempty"`
ModifyDate int `json:"modifyDate,omitempty"`
Space string `json:"space,omitempty"`
Organization ReducedOrganization `json:"organization,omitempty"`
Headers []CronjobHeader `json:"headers,omitempty"`
Body string `json:"body,omitempty"`
}
type CronjobCreation ¶ added in v0.0.21
type CronjobCreation struct {
Name string `json:"name,omitempty"`
Description string `json:"description,omitempty"`
Expression string `json:"expression,omitempty"`
Target string `json:"targetUrl,omitempty"`
Method CronjobHttpMethod `json:"httpMethod,omitempty"`
AcceptInvalidSSL bool `json:"acceptInvalidSSL,omitempty"`
Timezone string `json:"timezone,omitempty"`
Headers []CronjobHeader `json:"headers,omitempty"`
Body string `json:"body,omitempty"`
Enabled bool `json:"enabled,omitempty"`
}
type CronjobExpression ¶ added in v0.0.21
type CronjobExpression struct {
Expression string `json:"expression"`
}
type CronjobHeader ¶
type CronjobHttpMethod ¶ added in v0.0.21
type CronjobHttpMethod string
const ( GET CronjobHttpMethod = "GET" POST CronjobHttpMethod = "POST" PUT CronjobHttpMethod = "PUT" PATCH CronjobHttpMethod = "PATCH" DELETE CronjobHttpMethod = "DELETE" )
type CronjobInternal ¶ added in v0.0.21
type CronjobInternal struct {
Id string `json:"_id,omitempty"`
Enabled bool `json:"enabled,omitempty"`
Name string `json:"name,omitempty"`
Description string `json:"description,omitempty"`
Expression string `json:"expression,omitempty"`
Target string `json:"targetUrl,omitempty"`
Method CronjobHttpMethod `json:"httpMethod,omitempty"`
AcceptInvalidSSL bool `json:"acceptInvalidSSL,omitempty"`
Timezone string `json:"timezone,omitempty"`
Creator ReducedUser `json:"creator,omitempty"`
CreateDate int `json:"createDate,omitempty"`
ModifyDate int `json:"modifyDate,omitempty"`
SpaceId string `json:"spaceId,omitempty"`
OrganizationId string `json:"organizationId,omitempty"`
Headers []CronjobHeader `json:"headers,omitempty"`
Body string `json:"body,omitempty"`
}
type CronjobLog ¶ added in v0.0.21
type CronjobLog struct {
Id string `json:"_id,omitempty"`
CronjobId string `json:"cronjobId,omitempty"`
StatusCode int `json:"statusCode,omitempty"`
Organization ReducedOrganization `json:"organization,omitempty"`
Creator ReducedUser `json:"creator,omitempty"`
App string `json:"app,omitempty"`
Headers []CronjobHeader `json:"headers,omitempty"`
Body string `json:"body,omitempty"`
CreateDate int `json:"createDate,omitempty"`
ModifyDate int `json:"modifyDate,omitempty"`
}
type CronjobLogCreation ¶ added in v0.0.21
type CronjobLogCreation struct {
StatusCode int `json:"statusCode,omitempty"`
Headers []CronjobHeader `json:"headers,omitempty"`
Body string `json:"body,omitempty"`
}
type Event ¶
type Event struct {
Id string `json:"_id,omitempty"`
Name string `json:"name,omitempty"`
SpaceId string `json:"spaceId,omitempty"`
Organization ReducedOrganization `json:"organization,omitempty"`
Creator ReducedUser `json:"creator,omitempty"`
CreateDate int `json:"createDate,omitempty"` // UTC+0 unix timestamp
}
type EventCreation ¶
type EventCreation struct {
Name string `json:"name"`
}
type High5Space ¶ added in v0.0.21
type High5Space struct {
*Space
}
type NatsPermissions ¶
type NatsPermissions struct {
Email string `json:"email"`
Permissions struct {
Publish struct {
Deny []string `json:"deny"`
Allow []string `json:"allow"`
} `json:"publish"`
Subscribe struct {
Deny []string `json:"deny"`
Allow []string `json:"allow"`
} `json:"subscribe"`
Responses struct {
Max int `json:"max"`
TTL int `json:"ttl"`
} `json:"responses"`
} `json:"permissions"`
}
NatsPermissions represents a list of allowed subjects the active user token may subscribe / publish to after connection to nats
type OAuthApplication ¶ added in v0.0.21
type OAuthApplication struct {
Id string `json:"_id"`
Name string `json:"name"`
Description string `json:"description"`
Avatar string `json:"avatar"`
Homepage string `json:"homepage"`
Callback []string `json:"callback"`
ClientId string `json:"clientId"`
ClientSecret []OAuthApplicationClientSecret `json:"clientSecret"`
Organization ReducedOrganization `json:"organization"`
Creator ReducedUser `json:"creator"`
}
type OAuthApplicationClientSecret ¶ added in v0.0.21
type OAuthApplicationClientSecretCreation ¶ added in v0.0.21
type OAuthApplicationClientSecretCreation struct {
SecretName string `json:"secretName"`
}
type OAuthApplicationCreation ¶ added in v0.0.21
type OAuthApplicationCreation struct {
*OAuthApplicationUpdate
*OAuthApplicationClientSecretCreation
}
type OAuthApplicationUpdate ¶ added in v0.0.21
type Organization ¶
type Organization struct {
Id string `json:"_id,omitempty"`
Name string `json:"name,omitempty"`
Creator *User `json:"creator,omitempty"`
Company string `json:"company,omitempty"`
IsUserOrganization bool `json:"isUserOrganization"`
CreateDate int `json:"createDate"`
ModifyDate int `json:"modifyDate"`
Permission OrganizationPermission `json:"permission,omitempty"`
}
type OrganizationMember ¶
type OrganizationMemberCreation ¶ added in v0.0.21
type OrganizationMemberCreation struct {
Email string `json:"email"`
Permission OrganizationPermission `json:"permission"`
}
type OrganizationPermission ¶
type OrganizationPermission string
const ( ORGANIZATION_MEMBER OrganizationPermission = "MEMBER" ORGANIZATION_MANAGE OrganizationPermission = "MANAGE" ORGANIZATION_ADMIN OrganizationPermission = "ADMIN" ORGANIZATION_OWNER OrganizationPermission = "OWNER" )
type PatchOrganizationMemberPermission ¶ added in v0.0.21
type PatchOrganizationMemberPermission struct {
Permission OrganizationPermission `json:"permission"`
}
type PatchUser ¶
type PatchUser struct {
Name string `json:"name,omitempty"`
Email string `json:"email,omitempty"`
Company string `json:"company,omitempty"`
// ActiveOrganization holds the name for the active organization, mainly being used within the web frontend
// Changing this value makes all web frontend reload and act in the context of the new active organization
ActiveOrganization string `json:"activeOrganization,omitempty"`
}
type PatchWebhook ¶
type PatchWebhook struct {
Name string `json:"name"`
Event string `json:"event"`
Target string `json:"target"`
SecurityHeaders WebhookSecurityHeaders `json:"securityHeaders,omitempty"`
}
type Permission ¶
type Permission struct {
UserId string `json:"userId,omitempty"`
Permission SpacePermission `json:"permission,omitempty"`
}
func (Permission) String ¶
func (p Permission) String() string
type ReducedOrganization ¶ added in v0.0.21
type ReducedUser ¶ added in v0.0.21
type RegisterVerify ¶
type Scope ¶ added in v0.0.21
type Scope string
const ( HCLOUD_FULL Scope = "hcloud:full" IDP_EMAIL_READ Scope = "idp:email:read" IDP_USER_READ Scope = "idp:user:read" IDP_USER_WRITE Scope = "idp:user:write" IDP_USER_DELETE Scope = "idp:user:delete" IDP_ORGANIZATION_READ Scope = "idp:organization:read" IDP_ORGANIZATION_WRITE Scope = "idp:organization:write" IDP_ORGANIZATION_DELETE Scope = "idp:organization:delete" HIGH5_APP_READ Scope = "high5:app:read" HIGH5_APP_EXECUTE Scope = "high5:app:execute" HIGH5_APP_WRITE Scope = "high5:app:write" HIGH5_APP_DELETE Scope = "high5:app:delete" FUSE_APP_READ Scope = "fuse:app:read" FUSE_APP_EXECUTE Scope = "fuse:app:execute" FUSE_APP_WRITE Scope = "fuse:app:write" FUSE_APP_DELETE Scope = "fuse:app:delete" )
type SearchDateFilter ¶
type SearchDateFilter struct {
Date int `json:"date"`
Operator SearchDateOperator `json:"searchDateOperator"`
}
type SearchDateOperator ¶
type SearchDateOperator string
const ( EQ SearchDateOperator = "$eq" NE SearchDateOperator = "$ne" GTE SearchDateOperator = "$gte" GT SearchDateOperator = "$gt" LTE SearchDateOperator = "$lte" LT SearchDateOperator = "$lt" )
type SearchOrganizationFilter ¶
type SearchOrganizationFilter struct {
Name string `json:"name,omitempty"`
CreatorId string `json:"creatorId,omitempty"`
Company string `json:"company,omitempty"`
IsUserOrganization bool `json:"isUserOrganization,omitempty"`
CreateDateFilter SearchDateFilter `json:"createDateFilter,omitempty"`
ModifyDateFilter SearchDateFilter `json:"modifyDateFilter,omitempty"`
}
type Space ¶ added in v0.0.21
type Space struct {
Id string `json:"_id,omitempty"`
Name string `json:"name,omitempty"`
Permissions []Permission `json:"permissions,omitempty"`
Organization ReducedOrganization `json:"organization,omitempty"`
Creator ReducedUser `json:"creator,omitempty"`
CreateDate int `json:"createDate,omitempty"` // UTC+0 unix timestamp
}
type SpaceCreation ¶ added in v0.0.21
type SpaceCreation struct {
Name string `json:"name"`
}
type SpacePermission ¶ added in v0.0.21
type SpacePermission string
const ( NONE SpacePermission = "NONE" READ SpacePermission = "READ" EXECUTE SpacePermission = "EXECUTE" WRITE SpacePermission = "WRITE" MANAGE SpacePermission = "MANAGE" OWNER SpacePermission = "OWNER" )
type SpacePermissionPatch ¶ added in v0.0.21
type SpacePermissionPatch struct {
UserId string `json:"userId"`
// Use AppPermission.NONE to remove access
Permission SpacePermission `json:"permission"`
}
type Stream ¶
type Stream struct {
Id string `json:"_id,omitempty"`
Name string `json:"name,omitempty"`
EventId string `json:"eventId,omitempty"`
SpaceId string `json:"spaceId,omitempty"`
Order int `json:"order,omitempty"`
Organization ReducedOrganization `json:"organization,omitempty"`
Creator ReducedUser `json:"creator,omitempty"`
CreateDate int `json:"createDate,omitempty"` // UTC+0 unix timestamp
}
type StreamCreation ¶
type StreamCreation struct {
Name string `json:"name"`
}
type StreamExecutionPayload ¶
type StreamExecutionPayload struct {
Type StreamPayloadType `json:"type"`
Data string `json:"data"`
}
type StreamExecutionRequest ¶
type StreamExecutionRequest struct {
Target string `json:"target"`
Payload StreamExecutionPayload `json:"payload"`
Timeout int `json:"timeout"`
WaitForResult bool `json:"waitForResult"`
}
type StreamOrder ¶
type StreamPayloadType ¶
type StreamPayloadType string
const ( JSON StreamPayloadType = "json" GENERIC StreamPayloadType = "generic" )
type StreamResult ¶
type TOTPActivated ¶ added in v0.0.21
type TeamCreation ¶ added in v0.0.21
type TeamPatch ¶ added in v0.0.21
type TeamPatch struct {
Name string `json:"name"`
Users []string `json:"users"`
UserOperation TeamPatchUserOperation `json:"userOperation"`
}
type TeamPatchUserOperation ¶ added in v0.0.21
type TeamPatchUserOperation string
const ( ADD TeamPatchUserOperation = "ADD" REMOVE TeamPatchUserOperation = "REMOVE" SET TeamPatchUserOperation = "SET" )
type Total ¶
type Total int
Total represents the total amount of entities that exist in a paginated request
type UserPatCreation ¶ added in v0.0.21
type UserPatPatch ¶ added in v0.0.21
type UserPatType ¶ added in v0.0.21
type UserPatType string
const ( PAT UserPatType = "PAT" OAUTH UserPatType = "OAUTH" )
type Webhook ¶
type Webhook struct {
Id string `json:"_id,omitempty"`
Name string `json:"name,omitempty"`
Url string `json:"url,omitempty"`
Target string `json:"target"`
SecurityHeaders WebhookSecurityHeaders `json:"securityHeaders,omitempty"`
SpaceId string `json:"spaceId,omitempty"`
EventId string `json:"eventId,omitempty"`
Organization ReducedOrganization `json:"organization,omitempty"`
Creator ReducedUser `json:"creator,omitempty"`
CreateDate int `json:"createDate,omitempty"` // UTC+0 unix timestamp
ModifyDate int `json:"modifyDate,omitempty"` // UTC+0 unix timestamp
}
type WebhookCreation ¶
type WebhookCreation struct {
Name string `json:"name"`
Event string `json:"event"`
Target string `json:"target"`
SecurityHeaders WebhookSecurityHeaders `json:"securityHeaders,omitempty"`
}
type WebhookLog ¶
type WebhookLog struct {
Id string `json:"_id,omitempty"`
WebhookId string `json:"webhookId,omitempty"`
SpaceId string `json:"spaceId,omitempty"`
EventId string `json:"eventId,omitempty"`
OrganizationId string `json:"organizationId,omitempty"`
SourceIP string `json:"sourceIp,omitempty"`
CompleteHeader interface{} `json:"completeHeader,omitempty"`
RequestBody interface{} `json:"requestBody,omitempty"`
ResponseBody interface{} `json:"responseBody,omitempty"`
ResponseStatusCode int `json:"responseStatusCode,omitempty"`
Timestamp int `json:"timestamp,omitempty"` // UTC+0 unix timestamp
CreateDate int `json:"createDate,omitempty"` // UTC+0 unix timestamp
ModifyDate int `json:"modifyDate,omitempty"` // UTC+0 unix timestamp
}
type WebhookSecurityHeaders ¶
type WebhookSecurityHeaders struct {
}
Click to show internal directories.
Click to hide internal directories.